@@ -21,8 +21,8 @@
 #ifndef __GWEATHER_LOCATIONS_H__
 #define __GWEATHER_LOCATIONS_H__
 
-#ifndef GWEATHER_I_KNOW_THIS_IS_UNSTABLE
-#error "libgweather should only be used if you understand that it's subject to change, and is not supported as a fixed API/ABI or as part of the platform"
+#if !(defined(IN_GWEATHER_H) || defined(GWEATHER_COMPILATION))
+#error "gweather-location.h must not be included individually, include gweather.h instead"
 #endif
 
 #include <glib.h>
@@ -103,6 +103,8 @@ char                  *gweather_location_get_country_name (GWeatherLocation  *lo
 
 GWeatherLocation      *gweather_location_find_by_station_code (GWeatherLocation *world,
 							       const gchar      *station_code);
+GWeatherLocation      *gweather_location_find_by_country_code (GWeatherLocation *world,
+							       const gchar      *country_code);
 
 gboolean               gweather_location_equal          (GWeatherLocation  *one,
 							 GWeatherLocation  *two);
